@@ -1,20 +1,18 @@
-from django.conf import settings
+import jwt
 from rest_framework import exceptions
 from rest_framework.authentication import (BaseAuthentication,
                                            get_authorization_header)
-
 from rest_framework_jwt.settings import api_settings
-from rest_framework_jwt import jwt
 
 try:
     from django.contrib.auth import get_user_model
-except ImportError: # django < 1.5
-    from django.contrib.auth.models import User as UserModel
+except ImportError:  # Django < 1.5
+    from django.contrib.auth.models import User
 else:
-    UserModel = get_user_model()
+    User = get_user_model()
 
 
-jwt_decode_handler = api_settings.DEFAULT_JWT_DECODE_HANDLER
+jwt_decode_handler = api_settings.JWT_DECODE_HANDLER
 
 
 class JSONWebTokenAuthentication(BaseAuthentication):
@@ -22,9 +20,9 @@ class JSONWebTokenAuthentication(BaseAuthentication):
     Token based authentication using the JSON Web Token standard.
 
     Clients should authenticate by passing the token key in the "Authorization"
-    HTTP header, prepended with the string "Bearer ".  For example:
+    HTTP header, prepended with the string "JWT ".  For example:
 
-        Authorization: Bearer eyJhbGciOiAiSFMyNTYiLCAidHlwIj
+        Authorization: JWT eyJhbGciOiAiSFMyNTYiLCAidHlwIj
     """
     www_authenticate_realm = 'api'
 
@@ -35,14 +33,14 @@ class JSONWebTokenAuthentication(BaseAuthentication):
         """
         auth = get_authorization_header(request).split()
 
-        if not auth or auth[0].lower() != b'bearer':
+        if not auth or auth[0].lower() != b'jwt':
             return None
 
         if len(auth) == 1:
-            msg = 'Invalid bearer header. No credentials provided.'
+            msg = 'Invalid JWT header. No credentials provided.'
             raise exceptions.AuthenticationFailed(msg)
         elif len(auth) > 2:
-            msg = ('Invalid bearer header. Credentials string '
+            msg = ('Invalid JWT header. Credentials string '
                    'should not contain spaces.')
             raise exceptions.AuthenticationFailed(msg)
 
@@ -55,19 +53,19 @@ class JSONWebTokenAuthentication(BaseAuthentication):
             msg = 'Error decoding signature.'
             raise exceptions.AuthenticationFailed(msg)
 
-        user_id = payload['user_id']
-        user_email = payload['email']
-        user = self.authenticate_credentials(user_id, user_email)
+        user = self.authenticate_credentials(payload)
 
         return (user, auth[1])
 
-    def authenticate_credentials(self, user_id, email):
+    def authenticate_credentials(self, payload):
         """
         Returns an active user that matches the payload's user id and email.
         """
         try:
-            user = UserModel.objects.get(pk=user_id, email=email, is_active=True)
-        except UserModel.DoesNotExist:
+            user_id = payload['user_id']
+            email = payload['email']
+            user = User.objects.get(pk=user_id, email=email, is_active=True)
+        except User.DoesNotExist:
             msg = 'Invalid signature'
             raise exceptions.AuthenticationFailed(msg)
 
@@ -79,4 +77,4 @@ class JSONWebTokenAuthentication(BaseAuthentication):
         header in a `401 Unauthenticated` response, or `None` if the
         authentication scheme should return `403 Permission Denied` responses.
         """
-        return 'Bearer realm="{0}"'.format(self.www_authenticate_realm)
+        return 'JWT realm="{0}"'.format(self.www_authenticate_realm)
