@@ -1,10 +1,9 @@
 import json
+from jwt import base64url_decode
 
 from django.test import TestCase
 from django.contrib.auth.models import User
-
 from rest_framework_jwt import utils
-from rest_framework_jwt.jwt import base64url_decode
 
 
 class UtilsTests(TestCase):
